<?php
/**
 * Marketplace - Component Marketplace 
 * ******************************************************************
 *
 * PHP version 7.0
 *
 * @category   Component
 * @package    Joomla
 * @author     WebKul software private limited <support@webkul.com>
 * @copyright  2010 WebKul software private limited
 * @license    http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @version    GIT:5.2
 * @filesource http://store.webkul.com
 * @link       Technical Support:  webkul.uvdesk.com
 * ******************************************************************
 */
// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.view');
if (!class_exists('MarketplaceHelper')) {
    include JPATH_ADMINISTRATOR."components/com_marketplace/helpers.marketplace.php";
}
/**
 * MarketplaceViewAsktoadmin class
 * 
 * @category Component
 * @package  Joomla
 * @author   WebKul software private limited <support@webkul.com>
 * @license  http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link     Technical Support:  webkul.uvdesk.com
 */
class MarketplaceViewAsktoadmin extends JViewLegacy
{
    /**
     * This is display function
     *
     * @param boolean $cachable  view var
     * @param [type]  $urlparams view var
     * 
     * @return void
     */
    public function display($cachable = false, $urlparams = Array())
    {
        global $option;
        $userdetails = JFactory::getUser();
        $app = JFactory::getApplication();
        if (MarketplaceHelper::checkSeller($userdetails->id)) {
            parent::display();
        } else {
            $app->enqueueMessage(JText::_("PLZ_LOG_ASK_TO_ADMIN"), 'error');
        }
    }
}
